Page 97 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 97

Home

    If any one were to search behind the scenes for an
    identifiable organization that has worked to establish a
    Modern Day Babylon, it would be difficult to locate one
    more important than the Council on Foreign Relations
    headquartered in the Harold Pratt House, at 58 East 68th
    Street, in New York City. Former FBI Agent, Dan
    Smoot, labeled it, "The Invisible Government."

    In 1954 Norman Dodd met with CFR member Rowan

    Mr. Gaither said, "Mr. Dodd, we have asked you to
    come up here today because we thought that possibly,
    off the record, you would tell us why the Congress is
    interested in the activities of Foundations such as

    reply to that statement, Mr. Gaither then went on
    voluntarily and stated, "Mr. Dodd all of us that have a
    hand in making policies here have had experience either
    with the OSS during the war, or the European Economic
    Administration. After the war we have had experience

    1 ” . tat

    operating under directives, and these directives emanate,
    and did emanate from the White House. Now we still

    operate under just such directives. Would you like to
    know what the substance of these directives is?" I said,
    "Mr. Gaither, I'd like very much to know.' Whereupon he
    made this statement to me, namely, "Mr. Dodd, we here
    operate in response to similar directives, the substance of
    which is that we shall use our grant making powers so to
    alter life in the United States that it can be comfortably
    merged with the Soviet Union."®

    92

    The Secret Side of History

    Gaither who was at that time head of the Ford

    Foundation.

    This is Mr. Dodd's report of their

    conversation during that meeting:

    ourselves." And before I could think of how I would